@@ -1,6 +1,6 @@
 #ifndef lint
 static char const 
-yyrcsid[] = "$FreeBSD: src/usr.bin/yacc/skeleton.c,v 1.28.2.1 2001/07/19 05:46:39 peter Exp $";
+yyrcsid[] = "$FreeBSD: src/usr.bin/yacc/skeleton.c,v 1.34 2002/04/09 11:39:05 ru Exp $";
 #endif
 #include <stdlib.h>
 #define YYBYACC 1
@@ -25,8 +25,28 @@ static int yygrowstack();
 #include <fsi_data.h>
 #include <fsinfo.h>
 
+/* AIX requires this to be the first thing in the file. */
+#ifndef __GNUC__
+# if HAVE_ALLOCA_H
+#  include <alloca.h>
+# else /* not HAVE_ALLOCA_H */
+#  ifdef _AIX
+/*
+ * This pragma directive is indented so that pre-ANSI C compilers will
+ * ignore it, rather than choke on it.
+ */
+ #pragma alloca
+#  else /* not _AIX */
+#   ifndef alloca
+/* predefined by HP cc +Olibcalls */
+voidp alloca();
+#   endif /* not alloca */
+#  endif /* not _AIX */
+# endif /* not HAVE_ALLOCA_H */
+#endif /* not __GNUC__ */
+
 extern qelem *list_of_hosts, *list_of_automounts;
-#line 55 "../../fsinfo/fsi_gram.y"
+#line 75 "../../fsinfo/fsi_gram.y"
 typedef union {
 	auto_tree *a;
 	disk_fs *d;
@@ -37,7 +57,7 @@ typedef union {
 	fsi_mount *m;
 	fsmount *f;
 } YYSTYPE;
-#line 41 "fsi_gram.c"
+#line 61 "fsi_gram.c"
 #define YYERRCODE 256
 #define tARCH 257
 #define tAS 258
@@ -366,9 +386,9 @@ int
 yyparse (YYPARSE_PARAM_ARG)
     YYPARSE_PARAM_DECL
 {
-    register int yym, yyn, yystate;
+    int yym, yyn, yystate;
 #if YYDEBUG
-    register const char *yys;
+    const char *yys;
 
     if ((yys = getenv("YYDEBUG")))
     {
@@ -500,84 +520,84 @@ yyreduce:
     switch (yyn)
     {
 case 1:
-#line 111 "../../fsinfo/fsi_gram.y"
+#line 131 "../../fsinfo/fsi_gram.y"
 { yyval.q = new_que(); }
 break;
 case 2:
-#line 114 "../../fsinfo/fsi_gram.y"
+#line 134 "../../fsinfo/fsi_gram.y"
 { if (yyvsp[0].h) ins_que((qelem *) yyvsp[0].h, list_of_hosts->q_back);
 	    yyval.q = yyvsp[-1].q; }
 break;
 case 3:
-#line 118 "../../fsinfo/fsi_gram.y"
+#line 138 "../../fsinfo/fsi_gram.y"
 { if (yyvsp[0].a) ins_que((qelem *) yyvsp[0].a, list_of_automounts->q_back);
 	    yyval.q = yyvsp[-1].q; }
 break;
 case 4:
-#line 129 "../../fsinfo/fsi_gram.y"
+#line 149 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-2].h; yyval.h->h_disk_fs = yyvsp[-1].q; yyval.h->h_mount = yyvsp[0].q; }
 break;
 case 5:
-#line 132 "../../fsinfo/fsi_gram.y"
+#line 152 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-2].h; yyval.h->h_disk_fs = yyvsp[-1].q; yyval.h->h_mount = yyvsp[0].q; }
 break;
 case 6:
-#line 138 "../../fsinfo/fsi_gram.y"
+#line 158 "../../fsinfo/fsi_gram.y"
 { yyval.h = new_host(); set_host(yyval.h, HF_HOST, yyvsp[0].s); }
 break;
 case 7:
-#line 141 "../../fsinfo/fsi_gram.y"
+#line 161 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-2].h; set_host(yyval.h, HF_HOST, yyvsp[0].s); }
 break;
 case 8:
-#line 147 "../../fsinfo/fsi_gram.y"
+#line 167 "../../fsinfo/fsi_gram.y"
 { yyval.h = new_host(); }
 break;
 case 9:
-#line 150 "../../fsinfo/fsi_gram.y"
+#line 170 "../../fsinfo/fsi_gram.y"
 { if (yyvsp[-1].e) {
 		yyvsp[-1].e->e_if = yyvsp[-3].s;
 		yyval.h = yyvsp[-5].h; set_host(yyval.h, HF_ETHER, (char *) yyvsp[-1].e); }
 	  }
 break;
 case 10:
-#line 156 "../../fsinfo/fsi_gram.y"
+#line 176 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-2].h; set_host(yyval.h, HF_CONFIG, yyvsp[0].s); }
 break;
 case 11:
-#line 159 "../../fsinfo/fsi_gram.y"
+#line 179 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-3].h; set_host(yyval.h, HF_ARCH, yyvsp[0].s); }
 break;
 case 12:
-#line 162 "../../fsinfo/fsi_gram.y"
+#line 182 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-3].h; set_host(yyval.h, HF_OS, yyvsp[0].s); }
 break;
 case 13:
-#line 165 "../../fsinfo/fsi_gram.y"
+#line 185 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-3].h; set_host(yyval.h, HF_CLUSTER, yyvsp[0].s); }
 break;
 case 14:
-#line 168 "../../fsinfo/fsi_gram.y"
+#line 188 "../../fsinfo/fsi_gram.y"
 { yyerror("unknown host attribute"); }
 break;
 case 15:
-#line 173 "../../fsinfo/fsi_gram.y"
+#line 193 "../../fsinfo/fsi_gram.y"
 { yyval.e = new_ether_if(); }
 break;
 case 16:
-#line 176 "../../fsinfo/fsi_gram.y"
+#line 196 "../../fsinfo/fsi_gram.y"
 { yyval.e = yyvsp[-3].e; set_ether_if(yyval.e, EF_INADDR, yyvsp[0].s); }
 break;
 case 17:
-#line 178 "../../fsinfo/fsi_gram.y"
+#line 198 "../../fsinfo/fsi_gram.y"
 { yyval.e = yyvsp[-3].e; set_ether_if(yyval.e, EF_NETMASK, yyvsp[0].s); }
 break;
 case 18:
-#line 180 "../../fsinfo/fsi_gram.y"
+#line 200 "../../fsinfo/fsi_gram.y"
 { yyval.e = yyvsp[-3].e; set_ether_if(yyval.e, EF_HWADDR, yyvsp[0].s); }
 break;
 case 19:
-#line 190 "../../fsinfo/fsi_gram.y"
+#line 210 "../../fsinfo/fsi_gram.y"
 { if (yyvsp[0].q) {
 		yyval.a = new_auto_tree(yyvsp[-1].s, yyvsp[0].q);
 	    } else {
@@ -586,23 +606,23 @@ case 19:
 	  }
 break;
 case 20:
-#line 198 "../../fsinfo/fsi_gram.y"
+#line 218 "../../fsinfo/fsi_gram.y"
 { yyval.a = 0; }
 break;
 case 21:
-#line 203 "../../fsinfo/fsi_gram.y"
+#line 223 "../../fsinfo/fsi_gram.y"
 { yyval.s = strdup(""); }
 break;
 case 22:
-#line 206 "../../fsinfo/fsi_gram.y"
+#line 226 "../../fsinfo/fsi_gram.y"
 { yyval.s = yyvsp[0].s; }
 break;
 case 23:
-#line 211 "../../fsinfo/fsi_gram.y"
+#line 231 "../../fsinfo/fsi_gram.y"
 { yyval.q = 0; }
 break;
 case 24:
-#line 214 "../../fsinfo/fsi_gram.y"
+#line 234 "../../fsinfo/fsi_gram.y"
 { if (yyvsp[0].d) {
 		if (yyvsp[-1].q)
 			yyval.q = yyvsp[-1].q;
@@ -615,55 +635,55 @@ case 24:
 	  }
 break;
 case 25:
-#line 233 "../../fsinfo/fsi_gram.y"
+#line 253 "../../fsinfo/fsi_gram.y"
 { yyvsp[-1].d->d_dev = yyvsp[-3].s; yyval.d = yyvsp[-1].d; }
 break;
 case 26:
-#line 236 "../../fsinfo/fsi_gram.y"
-{ yyval.d = (disk_fs *) NULL; }
+#line 256 "../../fsinfo/fsi_gram.y"
+{ yyval.d = (disk_fs *) 0; }
 break;
 case 27:
-#line 252 "../../fsinfo/fsi_gram.y"
+#line 272 "../../fsinfo/fsi_gram.y"
 { yyval.d = new_disk_fs(); }
 break;
 case 28:
-#line 255 "../../fsinfo/fsi_gram.y"
+#line 275 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_FSTYPE, yyvsp[0].s); }
 break;
 case 29:
-#line 258 "../../fsinfo/fsi_gram.y"
+#line 278 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_OPTS, yyvsp[0].s); }
 break;
 case 30:
-#line 261 "../../fsinfo/fsi_gram.y"
+#line 281 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_PASSNO, yyvsp[0].s); }
 break;
 case 31:
-#line 264 "../../fsinfo/fsi_gram.y"
+#line 284 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_FREQ, yyvsp[0].s); }
 break;
 case 32:
-#line 267 "../../fsinfo/fsi_gram.y"
+#line 287 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-2].d; set_disk_fs(yyval.d, DF_MOUNT, (char *) yyvsp[0].q); }
 break;
 case 33:
-#line 270 "../../fsinfo/fsi_gram.y"
+#line 290 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_DUMPSET, yyvsp[0].s); }
 break;
 case 34:
-#line 273 "../../fsinfo/fsi_gram.y"
+#line 293 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_LOG, yyvsp[0].s); }
 break;
 case 35:
-#line 276 "../../fsinfo/fsi_gram.y"
+#line 296 "../../fsinfo/fsi_gram.y"
 { yyerror("unknown filesystem attribute"); }
 break;
 case 36:
-#line 290 "../../fsinfo/fsi_gram.y"
+#line 310 "../../fsinfo/fsi_gram.y"
 { yyval.q = 0; }
 break;
 case 37:
-#line 293 "../../fsinfo/fsi_gram.y"
+#line 313 "../../fsinfo/fsi_gram.y"
 { automount *a = new_automount(yyvsp[-3].s);
 	    a->a_volname = yyvsp[0].s;
 	    a->a_opts = yyvsp[-2].s;
@@ -675,7 +695,7 @@ case 37:
 	  }
 break;
 case 38:
-#line 303 "../../fsinfo/fsi_gram.y"
+#line 323 "../../fsinfo/fsi_gram.y"
 { automount *a = new_automount(yyvsp[-3].s);
             a->a_hardwiredfs = yyvsp[0].s;
             a->a_opts = yyvsp[-2].s;
@@ -687,7 +707,7 @@ case 38:
           }
 break;
 case 39:
-#line 314 "../../fsinfo/fsi_gram.y"
+#line 334 "../../fsinfo/fsi_gram.y"
 { automount *a = new_automount(yyvsp[-2].s);
 	    a->a_symlink = yyvsp[0].s;
 	    if (yyvsp[-3].q)
@@ -698,7 +718,7 @@ case 39:
 	  }
 break;
 case 40:
-#line 324 "../../fsinfo/fsi_gram.y"
+#line 344 "../../fsinfo/fsi_gram.y"
 { automount *a = new_automount(yyvsp[-4].s);
 	    a->a_mount = yyvsp[-1].q;
 	    a->a_opts = yyvsp[-3].s;
@@ -710,11 +730,11 @@ case 40:
 	  }
 break;
 case 41:
-#line 337 "../../fsinfo/fsi_gram.y"
+#line 357 "../../fsinfo/fsi_gram.y"
 { yyval.q = 0; }
 break;
 case 42:
-#line 340 "../../fsinfo/fsi_gram.y"
+#line 360 "../../fsinfo/fsi_gram.y"
 { yyvsp[-2].m->m_mount = yyvsp[-1].q;
 	    yyvsp[-2].m->m_name = yyvsp[-4].s;
 	    if (yyvsp[-4].s[0] != '/' && yyvsp[-4].s[1] && strchr(yyvsp[-4].s+1, '/'))
@@ -727,31 +747,31 @@ case 42:
 	  }
 break;
 case 43:
-#line 354 "../../fsinfo/fsi_gram.y"
+#line 374 "../../fsinfo/fsi_gram.y"
 { yyval.m = new_mount(); }
 break;
 case 44:
-#line 357 "../../fsinfo/fsi_gram.y"
+#line 377 "../../fsinfo/fsi_gram.y"
 { yyval.m = yyvsp[-2].m; set_mount(yyval.m, DM_EXPORTFS, yyvsp[0].s); }
 break;
 case 45:
-#line 360 "../../fsinfo/fsi_gram.y"
+#line 380 "../../fsinfo/fsi_gram.y"
 { yyval.m = yyvsp[-2].m; set_mount(yyval.m, DM_VOLNAME, yyvsp[0].s); }
 break;
 case 46:
-#line 363 "../../fsinfo/fsi_gram.y"
+#line 383 "../../fsinfo/fsi_gram.y"
 { yyval.m = yyvsp[-2].m; set_mount(yyval.m, DM_SEL, yyvsp[0].s); }
 break;
 case 47:
-#line 366 "../../fsinfo/fsi_gram.y"
+#line 386 "../../fsinfo/fsi_gram.y"
 { yyerror("unknown directory attribute"); }
 break;
 case 48:
-#line 376 "../../fsinfo/fsi_gram.y"
+#line 396 "../../fsinfo/fsi_gram.y"
 { yyval.q = 0; }
 break;
 case 49:
-#line 379 "../../fsinfo/fsi_gram.y"
+#line 399 "../../fsinfo/fsi_gram.y"
 { set_fsmount(yyvsp[0].f, FM_VOLNAME, yyvsp[-1].s);
 	    if (yyvsp[-3].q)
 		yyval.q = yyvsp[-3].q;
@@ -761,34 +781,34 @@ case 49:
 	    }
 break;
 case 50:
-#line 399 "../../fsinfo/fsi_gram.y"
+#line 419 "../../fsinfo/fsi_gram.y"
 { yyval.f = new_fsmount(); }
 break;
 case 51:
-#line 402 "../../fsinfo/fsi_gram.y"
+#line 422 "../../fsinfo/fsi_gram.y"
 { yyval.f = yyvsp[-1].f; set_fsmount(yyval.f, FM_DIRECT, ""); }
 break;
 case 52:
-#line 405 "../../fsinfo/fsi_gram.y"
+#line 425 "../../fsinfo/fsi_gram.y"
 { yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_LOCALNAME, yyvsp[0].s); }
 break;
 case 53:
-#line 408 "../../fsinfo/fsi_gram.y"
+#line 428 "../../fsinfo/fsi_gram.y"
 { yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_FROM, yyvsp[0].s); }
 break;
 case 54:
-#line 411 "../../fsinfo/fsi_gram.y"
+#line 431 "../../fsinfo/fsi_gram.y"
 { yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_FSTYPE, yyvsp[0].s); }
 break;
 case 55:
-#line 414 "../../fsinfo/fsi_gram.y"
+#line 434 "../../fsinfo/fsi_gram.y"
 { yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_OPTS, yyvsp[0].s); }
 break;
 case 56:
-#line 417 "../../fsinfo/fsi_gram.y"
+#line 437 "../../fsinfo/fsi_gram.y"
 { yyerror("unknown mount attribute"); }
 break;
-#line 792 "fsi_gram.c"
+#line 812 "fsi_gram.c"
     }
     yyssp -= yym;
     yystate = *yyssp;
